@@ -11,7 +11,7 @@ __author__ = "Shyue Ping Ong"
 __version__ = "1.1"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyuep@gmail.com"
-__status__ = "Beta"
+__status__ = "Production"
 __date__ = "Nov 19 2012"
 
 
@@ -23,6 +23,10 @@ class DelaunayTri(object):
     """
     Delaunay triangulation for a set of points.
 
+    .. attribute: dim
+
+        Dimension of the points.
+
     .. attribute: points
 
         Original points supplied.
@@ -41,7 +45,11 @@ class DelaunayTri(object):
                 [-0.5, 0.5], [0.5, -0.5], [0.5, 0.5]]
         """
         self.points = points
-        output = qdelaunay("i", points)
+        dim = map(len, self.points)
+        if max(dim) != min(dim):
+            raise ValueError("Input points must all have the same dimension!")
+        self.dim = dim[0]
+        output = qdelaunay("i Qt", points)
         output.pop(0)
         self.vertices = [[int(i) for i in row.strip().split()]
                          for row in output]
